DatapodDatabaseContext class
Annotation to define a database context and its associated entities and repositories.
- Annotations
-
- @Target.new({TargetKind.classType})
Constructors
-
DatapodDatabaseContext({required List<
Type> entities, required List<Type> repositories}) -
const
Properties
-
entities
→ List<
Type> -
The list of entity types managed by this database context.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
repositories
→ List<
Type> -
The list of repository types managed by this database context.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited